import { __decorate } from "tslib";
import { bodyFont } from '@microsoft/fast-components';
import { attr, customElement, DOM, FASTElement, observable } from '@microsoft/fast-element';
import { defaultBodyFont, EventName } from '../../types';
import { applyStyleChanges } from '../../utils/utils';
import { PreviewComponentsStyles as styles } from './preview-components.styles';
import { PreviewComponentsTemplate as template } from './preview-components.template';
let PreviewComponents = class PreviewComponents extends FASTElement {
    constructor() {
        super(...arguments);
        this.prefix = 'zero';
        this.buttonAppearanceAccent = 'primary-blue';
        this.buttonAppearanceNeutral = 'primary-grey';
        this.buttonAppearanceOutline = 'primary-gradient';
    }
    setDialogEventListeners() {
        this.showDialogTrigger.addEventListener('click', () => this.modal.show(), {
            passive: true,
        });
        this.closeDialogTrigger.addEventListener('click', () => this.modal.close(), {
            passive: true,
        });
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            this.handleStyleChanges(e);
        });
        document.body.addEventListener(EventName.DS_CHANGED, (e) => {
            this.handleDSChanges(e);
        });
        DOM.queueUpdate(() => {
            this.setDialogEventListeners();
            bodyFont.withDefault(defaultBodyFont);
        });
    }
    handleStyleChanges(e) {
        const detail = e.detail;
        if (detail) {
            DOM.queueUpdate(() => {
                applyStyleChanges(detail, this.provider);
            });
        }
    }
    handleDSChanges(event) {
        this.prefix = event.detail.prefix;
        this.buttonAppearanceAccent = event.detail.buttonAppearanceAccent;
        this.buttonAppearanceNeutral = event.detail.buttonAppearanceNeutral;
        this.buttonAppearanceOutline = event.detail.buttonAppearanceOutline;
        DOM.queueUpdate(() => {
            this.setDialogEventListeners();
        });
    }
};
__decorate([
    observable
], PreviewComponents.prototype, "modal", void 0);
__decorate([
    attr
], PreviewComponents.prototype, "prefix", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "buttonAppearanceAccent", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "buttonAppearanceNeutral", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "buttonAppearanceOutline", void 0);
__decorate([
    observable
], PreviewComponents.prototype, "provider", void 0);
PreviewComponents = __decorate([
    customElement({
        name: 'preview-components',
        template,
        styles,
    })
], PreviewComponents);
export { PreviewComponents };
